@@ -30,6 +30,8 @@ GUsbDevice	*_g_usb_device_new		(GUsbContext	*context,
                                                  GError        **error);
 
 libusb_device	*_g_usb_device_get_device	(GUsbDevice	*device);
+gboolean	 _g_usb_device_open_internal	(GUsbDevice	*device,
+						 GError		**error);
 
 G_END_DECLS
 
