@@ -31,7 +31,7 @@
 
 #include <string.h>
 
-#include <libusb-1.0/libusb.h>
+#include <libusb.h>
 
 #include "gusb-context.h"
 #include "gusb-context-private.h"
@@ -352,6 +352,8 @@ g_usb_device_libusb_error_to_gerror (GUsbDevice  *device,
 	case LIBUSB_ERROR_BUSY:
 		error_code = G_USB_DEVICE_ERROR_NO_DEVICE;
 		break;
+	default:
+		break;
 	}
 
 	g_set_error (error, G_USB_DEVICE_ERROR, error_code,
