@@ -23,6 +23,7 @@
 
 #include <glib.h>
 #include <gusb/gusb.h>
+#include <locale.h>
 #include <string.h>
 
 /**
@@ -482,6 +483,8 @@ main (int argc, char *argv[])
 		{ NULL}
 	};
 
+	setlocale (LC_ALL, "");
+
 	/* create helper object */
 	priv = g_slice_new0 (GUsbCmdPrivate);
 
